@@ -1,4 +1,4 @@
-// Copyright(C) 1999-2023 National Technology & Engineering Solutions
+// Copyright(C) 1999-2024 National Technology & Engineering Solutions
 // of Sandia, LLC (NTESS).  Under the terms of Contract DE-NA0003525 with
 // NTESS, the U.S. Government retains certain rights in this software.
 //
@@ -17,12 +17,12 @@ template <typename INT> class Assembly : public Exo_Entity
 public:
   Assembly();
   Assembly(int file_id, size_t assembly_id);
-  ~Assembly() override                        = default;
   Assembly(const Assembly &)                  = delete;
   const Assembly &operator=(const Assembly &) = delete;
 
   ex_entity_type                   Type() const { return assembly_type; }
   const std::vector<ex_entity_id> &Entities() const { return entities; }
+  size_t                           Size() const override { return entities.size(); }
 
 private:
   int  Check_State() const override;
