@@ -11,8 +11,8 @@
 
 #pragma once
 template <typename INT>
-void decompose_elements(const Ioss::Region &region, SystemInterface &interFace,
-                        std::vector<int> &elem_to_proc, IOSS_MAYBE_UNUSED INT dummy);
+std::vector<int> decompose_elements(const Ioss::Region &region, SystemInterface &interFace,
+                                    const std::vector<int> &weights, IOSS_MAYBE_UNUSED INT dummy);
 
 template <typename INT>
 void line_decomp_modify(const Ioss::chain_t<INT> &element_chains, std::vector<int> &elem_to_proc,
@@ -21,3 +21,7 @@ void line_decomp_modify(const Ioss::chain_t<INT> &element_chains, std::vector<in
 template <typename INT>
 void output_decomposition_statistics(const std::vector<INT> &elem_to_proc, int proc_count,
                                      size_t number_elements);
+
+template <typename INT>
+std::vector<int> line_decomp_weights(const Ioss::chain_t<INT> &element_chains,
+                                     size_t                    element_count);
