@@ -46,13 +46,13 @@ namespace Ioss {
   public:
     BlockDecompositionData() = default;
 
-    const std::string &name() const { return name_; }
-    int                zone() const { return zone_; }
-    int                section() const { return section_; }
-    int64_t            id() const { return id_; }
-    size_t             file_count() const { return fileCount; }
-    size_t             ioss_count() const { return iossCount; }
-    size_t             global_count() const { return globalCount; }
+    IOSS_NODISCARD const std::string &name() const { return name_; }
+    IOSS_NODISCARD int                zone() const { return zone_; }
+    IOSS_NODISCARD int                section() const { return section_; }
+    IOSS_NODISCARD int64_t            id() const { return id_; }
+    IOSS_NODISCARD size_t             file_count() const { return fileCount; }
+    IOSS_NODISCARD size_t             ioss_count() const { return iossCount; }
+    IOSS_NODISCARD size_t             global_count() const { return globalCount; }
 
     std::string name_{};
     int         zone_{0};
@@ -102,14 +102,17 @@ namespace Ioss {
       }
     }
 
-    const std::string &name() const { return name_; }
-    const std::string &ss_name() const { return ss_name_.empty() ? name_ : ss_name_; }
-    int64_t            id() const { return id_; }
-    int                zone() const { return zone_; }
-    int                section() const { return section_; }
-    size_t             file_count() const { return fileCount; }
-    size_t             ioss_count() const { return entitylist_map.size(); }
-    size_t             df_count() const { return distributionFactorCount; }
+    IOSS_NODISCARD const std::string &name() const { return name_; }
+    IOSS_NODISCARD const std::string &ss_name() const
+    {
+      return ss_name_.empty() ? name_ : ss_name_;
+    }
+    IOSS_NODISCARD int64_t id() const { return id_; }
+    IOSS_NODISCARD int     zone() const { return zone_; }
+    IOSS_NODISCARD int     section() const { return section_; }
+    IOSS_NODISCARD size_t  file_count() const { return fileCount; }
+    IOSS_NODISCARD size_t  ioss_count() const { return entitylist_map.size(); }
+    IOSS_NODISCARD size_t  df_count() const { return distributionFactorCount; }
 
     // contains global entity-list positions for all entities in this set on this processor.
     std::vector<size_t> entitylist_map;
@@ -144,29 +147,32 @@ namespace Ioss {
     ElementBlockBatchOffset(const ElementBlockBatchOffset &) = delete;
     ElementBlockBatchOffset(ElementBlockBatchOffset &&)      = delete;
 
-    size_t get_ioss_element_size(const std::vector<int64_t> &blockSubsetIndex) const;
+    IOSS_NODISCARD size_t get_ioss_element_size(const std::vector<int64_t> &blockSubsetIndex) const;
 
-    std::vector<size_t> get_ioss_offset(const std::vector<int64_t> &blockSubsetIndex,
-                                        const std::vector<int>     &blockComponentCount) const;
+    IOSS_NODISCARD std::vector<size_t>
+                   get_ioss_offset(const std::vector<int64_t> &blockSubsetIndex,
+                                   const std::vector<int>     &blockComponentCount) const;
 
-    std::vector<size_t> get_import_offset(const std::vector<int64_t> &blockSubsetIndex,
-                                          const std::vector<int>     &blockComponentCount) const;
+    IOSS_NODISCARD std::vector<size_t>
+                   get_import_offset(const std::vector<int64_t> &blockSubsetIndex,
+                                     const std::vector<int>     &blockComponentCount) const;
 
-    size_t get_connectivity_ioss_offset_size(const std::vector<int64_t> &blockSubsetIndex) const;
+    IOSS_NODISCARD size_t
+    get_connectivity_ioss_offset_size(const std::vector<int64_t> &blockSubsetIndex) const;
 
-    std::vector<int>
+    IOSS_NODISCARD std::vector<int>
     get_connectivity_ioss_component_count(const std::vector<int64_t> &blockSubsetIndex) const;
 
   private:
     const std::vector<BlockDecompositionData> &m_data;
 
-    size_t get_ioss_offset_size(const std::vector<int64_t> &blockSubsetIndex,
-                                const std::vector<int>     &blockComponentCount) const;
+    IOSS_NODISCARD size_t get_ioss_offset_size(const std::vector<int64_t> &blockSubsetIndex,
+                                               const std::vector<int> &blockComponentCount) const;
 
-    std::vector<size_t>
-    get_connectivity_ioss_offset(const std::vector<int64_t> &blockSubsetIndex) const;
+    IOSS_NODISCARD std::vector<size_t>
+                   get_connectivity_ioss_offset(const std::vector<int64_t> &blockSubsetIndex) const;
 
-    std::vector<size_t>
+    IOSS_NODISCARD std::vector<size_t>
     get_connectivity_import_offset(const std::vector<int64_t> &blockSubsetIndex) const;
   };
 
@@ -179,16 +185,19 @@ namespace Ioss {
     Decomposition &operator=(Decomposition const &) = default;
     Decomposition &operator=(Decomposition &&)      = default;
 
-    size_t global_node_count() const { return m_globalNodeCount; }
-    size_t global_elem_count() const { return m_globalElementCount; }
-    size_t ioss_node_count() const { return nodeGTL.size(); }
-    size_t ioss_elem_count() const { return localElementMap.size() + importElementMap.size(); }
-    size_t file_node_count() const { return m_nodeCount; }
-    size_t file_elem_count() const { return m_elementCount; }
-    size_t file_node_offset() const { return m_nodeOffset; }
-    size_t file_elem_offset() const { return m_elementOffset; }
+    IOSS_NODISCARD size_t global_node_count() const { return m_globalNodeCount; }
+    IOSS_NODISCARD size_t global_elem_count() const { return m_globalElementCount; }
+    IOSS_NODISCARD size_t ioss_node_count() const { return nodeGTL.size(); }
+    IOSS_NODISCARD size_t ioss_elem_count() const
+    {
+      return localElementMap.size() + importElementMap.size();
+    }
+    IOSS_NODISCARD size_t file_node_count() const { return m_nodeCount; }
+    IOSS_NODISCARD size_t file_elem_count() const { return m_elementCount; }
+    IOSS_NODISCARD size_t file_node_offset() const { return m_nodeOffset; }
+    IOSS_NODISCARD size_t file_elem_offset() const { return m_elementOffset; }
 
-    bool needs_centroids() const
+    IOSS_NODISCARD bool needs_centroids() const
     {
       return (m_method == "RCB" || m_method == "RIB" || m_method == "HSFC" ||
               m_method == "GEOM_KWAY" || m_method == "KWAY_GEOM" || m_method == "METIS_SFC");
@@ -197,14 +206,14 @@ namespace Ioss {
     void generate_entity_distributions(size_t global_node_count, size_t global_element_count);
 
     // T/F if node with global index node owned by this processors ioss-decomp.
-    bool i_own_node(size_t global_index) const
+    IOSS_NODISCARD bool i_own_node(size_t global_index) const
     {
       // global_index is 1-based index into global list of nodes [1..global_node_count]
       return std::binary_search(nodeGTL.begin(), nodeGTL.end(), global_index);
     }
 
     // T/F if element with global index elem owned by this processors ioss-decomp.
-    bool i_own_elem(size_t global_index) const
+    IOSS_NODISCARD bool i_own_elem(size_t global_index) const
     {
       // global_index is 1-based index into global list of elements [1..global_element_count]
 #if defined(DC_USE_VECTOR)
@@ -218,7 +227,7 @@ namespace Ioss {
 #endif
     }
 
-    size_t node_global_to_local(size_t global_index) const
+    IOSS_NODISCARD size_t node_global_to_local(size_t global_index) const
     {
       // global_index is 1-based index into global list of nodes [1..global_node_count]
       // return value is 1-based index into local list of nodes on this
@@ -231,7 +240,7 @@ namespace Ioss {
       return std::distance(nodeGTL.begin(), I) + 1; // Convert to 1-based index.
     }
 
-    size_t elem_global_to_local(size_t global_index) const
+    IOSS_NODISCARD size_t elem_global_to_local(size_t global_index) const
     {
       // global_index is 1-based index into global list of elements [1..global_node_count]
       // return value is 1-based index into local list of elements on this
@@ -240,12 +249,12 @@ namespace Ioss {
       auto I = lower_bound(
           elemGTL.begin(), elemGTL.end(), global_index,
           [](const std::pair<INT, INT> &lhs, INT val) -> bool { return lhs.first < val; });
-      assert(I != elemGTL.end() && I->first == global_index);
+      assert(I != elemGTL.end() && I->first == (INT)global_index);
 #else
       auto I = elemGTL.find(global_index);
 #endif
       assert(I != elemGTL.end());
-      assert(I->first == global_index);
+      assert(I->first == (INT)global_index);
       return I->second;
     }
 
@@ -555,7 +564,7 @@ namespace Ioss {
     }
 
     template <typename T, typename U>
-    std::vector<size_t> do_communicate_entity_data(
+    IOSS_NODISCARD std::vector<size_t> do_communicate_entity_data(
         T *file_data, U *ioss_data, const std::vector<BlockDecompositionData> &blocks,
         const std::vector<int64_t> &blockSubsetIndex, const std::vector<size_t> &fileOffset,
         const std::vector<int> &blockComponentCount) const
@@ -665,11 +674,10 @@ namespace Ioss {
     }
 
     template <typename T, typename U>
-    std::vector<size_t> communicate_entity_data(T *file_data, U *ioss_data,
-                                                const std::vector<BlockDecompositionData> &blocks,
-                                                const std::vector<int64_t> &blockSubsetIndex,
-                                                const std::vector<size_t>  &fileOffset,
-                                                const std::vector<int> &blockComponentCount) const
+    IOSS_NODISCARD std::vector<size_t> communicate_entity_data(
+        T *file_data, U *ioss_data, const std::vector<BlockDecompositionData> &blocks,
+        const std::vector<int64_t> &blockSubsetIndex, const std::vector<size_t> &fileOffset,
+        const std::vector<int> &blockComponentCount) const
     {
       show_progress(__func__);
       if (m_method == "LINEAR") {
