@@ -1,4 +1,4 @@
-// Copyright(C) 1999-2020, 2022 National Technology & Engineering Solutions
+// Copyright(C) 1999-2020, 2022, 2024 National Technology & Engineering Solutions
 // of Sandia, LLC (NTESS).  Under the terms of Contract DE-NA0003525 with
 // NTESS, the U.S. Government retains certain rights in this software.
 //
@@ -16,13 +16,17 @@ namespace Ioss {
   class IOSS_EXPORT ElementVariableType : public Ioss::VariableType
   {
   public:
-    std::string label(int /*which*/, const char /*suffix_sep*/) const override { return ""; }
-    std::string label_name(const std::string &base, int /*which*/, const char /*suffix_sep*/,
-                           bool /* suffices_uppercase */) const override
+    IOSS_NODISCARD std::string label(int /*which*/, const char /*suffix_sep*/) const override
+    {
+      return "";
+    }
+    IOSS_NODISCARD std::string label_name(const std::string &base, int /*which*/,
+                                          const char /*suffix_sep*/,
+                                          bool /* suffices_uppercase */) const override
     {
       return base;
     }
-    int suffix_count() const override { return 0; }
+    IOSS_NODISCARD int suffix_count() const override { return 0; }
 
   protected:
     ElementVariableType(const std::string &type, int comp_count);
