@@ -74,13 +74,13 @@ namespace Ioss {
     }                                                                                              \
   } while (0)
 
-inline auto format_as(CGNS_ENUMT(BCType_t) t) { return BCTypeName[t]; }
-inline auto format_as(CGNS_ENUMT(DataType_t) t) { return DataTypeName[t]; }
-inline auto format_as(CGNS_ENUMT(ElementType_t) t) { return ElementTypeName[t]; }
-inline auto format_as(CGNS_ENUMT(GridConnectivityType_t) t) { return GridConnectivityTypeName[t]; }
-inline auto format_as(CGNS_ENUMT(GridLocation_t) t) { return GridLocationName[t]; }
-inline auto format_as(CGNS_ENUMT(PointSetType_t) t) { return PointSetTypeName[t]; }
-inline auto format_as(CGNS_ENUMT(ZoneType_t) t) { return ZoneTypeName[t]; }
+IOSS_NODISCARD inline auto format_as(CGNS_ENUMT(BCType_t) t) { return BCTypeName[t]; }
+IOSS_NODISCARD inline auto format_as(CGNS_ENUMT(DataType_t) t) { return DataTypeName[t]; }
+IOSS_NODISCARD inline auto format_as(CGNS_ENUMT(ElementType_t) t) { return ElementTypeName[t]; }
+IOSS_NODISCARD inline auto format_as(CGNS_ENUMT(GridConnectivityType_t) t) { return GridConnectivityTypeName[t]; }
+IOSS_NODISCARD inline auto format_as(CGNS_ENUMT(GridLocation_t) t) { return GridLocationName[t]; }
+IOSS_NODISCARD inline auto format_as(CGNS_ENUMT(PointSetType_t) t) { return PointSetTypeName[t]; }
+IOSS_NODISCARD inline auto format_as(CGNS_ENUMT(ZoneType_t) t) { return ZoneTypeName[t]; }
 
 namespace Iocgns {
   class StructuredZoneData;
@@ -100,20 +100,20 @@ namespace Iocgns {
   class IOCGNS_EXPORT Utils
   {
   public:
-    static std::pair<std::string, int> decompose_name(const std::string &name, bool is_parallel);
-    static std::string                 decompose_sb_name(const std::string &name);
+    IOSS_NODISCARD static std::pair<std::string, int> decompose_name(const std::string &name, bool is_parallel);
+    IOSS_NODISCARD static std::string                 decompose_sb_name(const std::string &name);
 
-    static size_t index(const Ioss::Field &field);
+    IOSS_NODISCARD static size_t index(const Ioss::Field &field);
 
     static void cgns_error(int cgnsid, const char *file, const char *function, int lineno,
                            int processor);
 
     static void update_db_zone_property(int cgns_file_ptr, const Ioss::Region *region,
                                         int myProcessor, bool is_parallel, bool is_parallel_io);
-    static int  get_db_zone(const Ioss::GroupingEntity *entity);
+    IOSS_NODISCARD static int  get_db_zone(const Ioss::GroupingEntity *entity);
     static void set_field_index(const Ioss::Field &field, size_t index,
                                 CGNS_ENUMT(GridLocation_t) location);
-    static bool is_cell_field(const Ioss::Field &field);
+    IOSS_NODISCARD static bool is_cell_field(const Ioss::Field &field);
 
     template <typename INT>
     static void map_cgns_connectivity(const Ioss::ElementTopology *topo, size_t element_count,
@@ -274,7 +274,7 @@ namespace Iocgns {
       }
     }
 
-    static std::vector<ZoneBC> parse_zonebc_sideblocks(int cgns_file_ptr, int base, int zone,
+    IOSS_NODISCARD static std::vector<ZoneBC> parse_zonebc_sideblocks(int cgns_file_ptr, int base, int zone,
                                                        int myProcessor);
 
     static void
@@ -286,9 +286,9 @@ namespace Iocgns {
                                              int state, const int *vertex_solution_index,
                                              const int *cell_center_solution_index,
                                              bool       is_parallel_io);
-    static int  find_solution_index(int cgns_file_ptr, int base, int zone, int step,
+    IOSS_NODISCARD static int  find_solution_index(int cgns_file_ptr, int base, int zone, int step,
                                     CGNS_ENUMT(GridLocation_t) location);
-    static Ioss::MeshType check_mesh_type(int cgns_file_ptr);
+    IOSS_NODISCARD static Ioss::MeshType check_mesh_type(int cgns_file_ptr);
 
     static void output_assembly(int file_ptr, const Ioss::Assembly *assembly, bool is_parallel_io,
                                 bool appending = false);
@@ -299,11 +299,11 @@ namespace Iocgns {
     static size_t common_write_meta_data(int file_ptr, const Ioss::Region &region,
                                          std::vector<size_t> &zone_offset, bool is_parallel);
     static size_t resolve_nodes(Ioss::Region &region, int my_processor, bool is_parallel);
-    static std::vector<std::vector<std::pair<size_t, size_t>>>
+    IOSS_NODISCARD static std::vector<std::vector<std::pair<size_t, size_t>>>
     resolve_processor_shared_nodes(Ioss::Region &region, int my_processor);
 
-    static CGNS_ENUMT(ElementType_t) map_topology_to_cgns(const std::string &name);
-    static std::string map_cgns_to_topology_type(CGNS_ENUMT(ElementType_t) type);
+    IOSS_NODISCARD static CGNS_ENUMT(ElementType_t) map_topology_to_cgns(const std::string &name);
+    IOSS_NODISCARD static std::string map_cgns_to_topology_type(CGNS_ENUMT(ElementType_t) type);
     static void        add_sidesets(int cgns_file_ptr, Ioss::DatabaseIO *db);
     static void        add_assemblies(int cgns_file_ptr, Ioss::DatabaseIO *db);
     static void add_to_assembly(int cgns_file_ptr, Ioss::Region *region, Ioss::EntityBlock *block,
@@ -332,7 +332,7 @@ namespace Iocgns {
                           double load_balance, int proc_rank, int proc_count, bool verbose);
     static void assign_zones_to_procs(std::vector<Iocgns::StructuredZoneData *> &zones,
                                       std::vector<size_t> &work_vector, bool verbose);
-    static std::string show_config();
+    IOSS_NODISCARD static std::string show_config();
 
     template <typename INT>
     static void generate_block_faces(Ioss::ElementTopology *topo, size_t num_elem,
